import styled from 'styled-components'
import { AppBar, Box, createMuiTheme } from '@material-ui/core'

const { breakpoints } = createMuiTheme()

export const StyledContainer = styled(Box)`
  display: flex;
  flex-direction: column;
  height: 100vh;
  background: ${props => props.color};
  overflow: hidden;


  .container {
    flex-grow: 1;
    display: flex;
    flex-direction: column;
    height: 80vh;
    overflow: auto;

    @media(min-width: 900px) {
      height: 80vh;
      max-width: 80%; 
    }
  }
`

export const Content = styled(Box)`
  flex-grow: 1;
  display: flex;
  flex-direction: column;
  justify-content: center;
  overflow: hidden;
  padding: 1rem 0;
  padding-bottom: 0;
  #close{
    position: absolute;
    right: 1rem;
    top: 1rem;
    width: 4vw;
    z-index: 100;
    @media(max-width:900px){
      width: 10vw
    }
  }
  #close:hover{
    cursor: pointer;
    transform: scale( 1.1)
  }
  h2 {
    font-weight: 600;
    margin-top: 1vh;
    margin-bottom: 2vh;
    @media(max-width: 900px){
      margin-bottom: 1vh; 
      font-size: 3.5vh;
    }
  }
  #title{
    font-weight: bold;
    margin-top: 1vh;
    margin-bottom: 3vh;
    @media(max-width: 900px){
      margin-left: 1rem;
      margin-bottom: 2vh;
    }
  }
  #content {
    overflow-x: hidden;
    flex-grow: 1;
    display: flex;
    flex-direction: column;
    position: relative;
  }
  
`

export const Header = styled(Box)`
  padding: 0.5rem;
  background-color: #0f75a2;

  .endbutton {
    flex-grow: 1;
    display: flex;
    justify-content: flex-end;
  }
`
export const Footer = styled(Box)`
  padding: 0.5rem;
  background-color: #0f75a2;

  .middlebutton {
    flex-grow: 1;
    display: flex;
    justify-content: center;
  }
`

export const MenuButton = styled.button`
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: #DEE7EE;
  color: #2F414C;
  width: 45px;
  height: 45px;
  border-radius: 50%;
  border: none;
  box-shadow: 0 1px 3px rgba(0,0,0,0.12), 0 1px 2px rgba(0,0,0,0.24);
  transition: all 0.3s cubic-bezier(.25,.8,.25,1);
  margin-left: ${props => props.mleft? "1rem" : "0"};
  transition: 0.2s linear;
  cursor: pointer;

  @media(min-width: 900px) {
    width: 3.5rem;
    height: 3.5rem;
  }
  
  &:hover {
    background-color: #B9D3E7;
    box-shadow: 0 7px 14px rgba(0,0,0,0.25), 0 5px 5px rgba(0,0,0,0.22);
    transition: all 0.3s cubic-bezier(.25,.8,.25,1);
  }

  &:focus {
    outline: none;
  }

  ${props => props.disabled? "opacity: 0; pointer-events: none;" : "opacity: 1"};
`

export const DefPage = styled(Box)`
    flex-grow: 1;
    display: flex;
    flex-direction: column;
    overflow: hidden;
    @media(max-width: 900px){
      margin: 1rem;
      overflow-y: auto;
    }
`
