import React, { useRef, useImperativeHandle, forwardRef } from "react"

import Drawer from '../Drawer'

import { Toolbar, Tooltip } from '@material-ui/core'
import { HelpOutline } from "@material-ui/icons"
import { StyledHeader } from "./styles"

import btn_home from '../../assets/buttons/btn_home.svg'
import RoundButton from "../RoundButton"

const Header = (props, ref) => {
  const { help, download, nohome, cover } = props
  const drawerref = useRef(Drawer)

  const openDrawer = async (key) => {
    if(!drawerref.current){
        return
    }

    await drawerref.current.openDrawer(key)
    drawerref.current.scrollList()
  }

  useImperativeHandle(ref, () => ({
    openRef: key => {
      openDrawer(key)
    }
  }))

  return (
    <StyledHeader cover={cover}>
      <Toolbar>
        <Drawer ref={drawerref}/>
        {
          nohome?
          <></>
          :
          <RoundButton tooltip="Início" to="/" type="home" margin={true}/>
        }       
        <div className="endbutton">
          {
            help?
              <RoundButton tooltip="Ajuda" type="help" margin/>
            :
              <RoundButton disabled/>
          }
          {
            download?
              <RoundButton tooltip="Versão pdf" type="download" margin/>            
            :
              <RoundButton disabled/>
          }
        </div>
      </Toolbar>
    </StyledHeader>
  )
}

export default forwardRef(Header)
