import React from 'react'
import { Link } from 'react-router-dom'
import styled from 'styled-components'

import arrow from "../../assets/buttons/seta.svg"
import arrow_disabled from "../../assets/buttons/seta_disabled.svg"

const ArrowPrev = styled(Link)`
    display: flex;
    justify-content: center;
    align-items: center;
    position: relative;
    padding: 2px;
    transition: 150ms ease;

    img {
        width: 2.5rem;
        
        @media(min-width: 900px) {
            width: 4rem;     
        }
    }

    &:hover {
        filter: brightness(120%);
        transform: scale(1.2);
    }

    .reverse {
        transform: rotate(180deg);
    }

    ${props => props.disabled? "pointer-events: none" : ""};
`
const ArrowNext = styled(Link)`
    display: flex;
    justify-content: center;
    align-items: center;
    padding: 2px;
    transition: 150ms ease;

    img {
        width: 2.5rem;
        
        @media(min-width: 900px) {
            width: 4rem;     
        }
    }
    
    &:hover {
        filter: brightness(120%);
        transform: scale(1.2);
    }

    .reverse {
        transform: rotate(180deg);
    }

    ${props => props.disabled? "pointer-events: none" : ""};
`

export function Prev(props) {
    const { to, disabled } = props

    return (
        <>
        {
            disabled?
            <ArrowPrev replace disabled>
                <img src={arrow_disabled} alt=""/>
            </ArrowPrev>
            :
            <ArrowPrev to={to}>
                <img src={arrow} alt="" className="reverse"/>
            </ArrowPrev>
        }
        </>
    )
}

export function Next(props) {
    const { to, disabled } = props

    return (
        <>
        {
            disabled?
            <ArrowNext disabled>
                <img src={arrow_disabled} alt="" className="reverse"/>
            </ArrowNext>
            :
            <ArrowNext to={to}>
                <img src={arrow} alt=""/>
            </ArrowNext>
        }
        </>
    )
}
