import styled from 'styled-components'
import { Link } from 'react-router-dom'

export const Button = styled(Link)`
  display: flex;
  align-items: center;
  justify-content: center;
  /* overflow: hidden; */
  background-color: ${props => props.color? props.color : props.theme.palette.button.background};
  color: ${props => props.theme.palette.button.icon};
  width: 45px;
  height: 45px;
  border-radius: 50%;
  border: none;
  transition: all 0.3s cubic-bezier(.25,.8,.25,1);
  margin-left: ${props => props.margin ? "1rem" : "0"};
  transition: 0.2s linear;
  position: relative;
  cursor: pointer;

  /* -webkit-box-shadow: -2px 2px 4px 0px rgba(0,0,0,0.5);
     -moz-box-shadow: -2px 2px 4px 0px rgba(0,0,0,0.5);
          box-shadow: -2px 2px 4px 0px rgba(0,0,0,0.5); */

  box-shadow: 4px 10px 28px rgba(0,0,0,0.25), 4px 6px 10px rgba(0,0,0,0.22);
  transition: all 0.3s cubic-bezier(.25,.8,.25,1);

  @media(min-width: 900px) {
    width: 3.5rem;
    height: 3.5rem;
    min-width: 60px;
    min-height: 60px;
  }
  
  &:hover {
    background-color: #B9D3E7;
    /* box-shadow: 0 7px 14px rgba(0,0,0,0.25), 0 5px 5px rgba(0,0,0,0.22); */
    box-shadow: 0 19px 38px rgba(0,0,0,0.30), 0 15px 12px rgba(0,0,0,0.22);

    /* -webkit-box-shadow: -4px 4px 8px 0px rgba(0,0,0,0.5);
       -moz-box-shadow: -4px 4px 8px 0px rgba(0,0,0,0.5);
            box-shadow: -4px 4px 8px 0px rgba(0,0,0,0.5); */
  }

  &:focus {
    outline: none;
  }

  &::after {
    --scale: 0;
    content: attr(data-tooltip);
    position: absolute;
    top: 4.5rem;
    padding: 0.5rem;
    width: 4rem;
    text-align: center;
    word-break: break-word;
    background: ${props => props.theme.palette.secondary.dark};
    color: ${props => props.theme.palette.background.main};
    border-radius: 5px;
    box-shadow: 0 1px 3px rgba(0,0,0,0.12), 0 1px 2px rgba(0,0,0,0.24);
    transform: scale(var(--scale));
    transition: 150ms transform;
    transform-origin: top center;
    z-index: 2;
  }

  &:hover::after {
    --scale: 1;
  }

  img {
    width: 100%;
  }

  ${props => props.disabled? "opacity: 0; pointer-events: none;" : "opacity: 1"};
`

export const ActionButton = styled.button`
  display: flex;
  align-items: center;
  justify-content: center;
  overflow: hidden;
  background-color: ${props => props.color? props.color : props.theme.palette.button.background};
  color: ${props => props.theme.palette.button.icon};
  width: 45px;
  height: 45px;
  border-radius: 50%;
  border: none;
  transition: all 0.3s cubic-bezier(.25,.8,.25,1);
  margin-left: ${props => props.margin ? "1rem" : "0"};
  transition: 0.2s linear;
  cursor: pointer;

  /* -webkit-box-shadow: -2px 2px 4px 0px rgba(0,0,0,0.5);
     -moz-box-shadow: -2px 2px 4px 0px rgba(0,0,0,0.5);
          box-shadow: -2px 2px 4px 0px rgba(0,0,0,0.5); */

  box-shadow: 4px 10px 28px rgba(0,0,0,0.25), 4px 6px 10px rgba(0,0,0,0.22);

  @media(min-width: 900px) {
    width: 3.5rem;
    height: 3.5rem;
    min-width: 60px;
    min-height: 60px;
  }
  
  &:hover {
    background-color: #B9D3E7;
    transition: all 0.3s cubic-bezier(.25,.8,.25,1);
    box-shadow: 0 19px 38px rgba(0,0,0,0.30), 0 15px 12px rgba(0,0,0,0.22);

    /* -webkit-box-shadow: -4px 4px 8px 0px rgba(0,0,0,0.5);
       -moz-box-shadow: -4px 4px 8px 0px rgba(0,0,0,0.5);
            box-shadow: -4px 4px 8px 0px rgba(0,0,0,0.5); */
  }

  &:focus {
    outline: none;
  }

  &::after {
    --scale: 0;
    content: attr(data-tooltip);
    position: absolute;
    top: 4.5rem;
    padding: .5rem;
    text-align: center;
    word-break: break-word;
    background: ${props => props.theme.palette.secondary.dark};
    color: ${props => props.theme.palette.background.main};
    border-radius: 5px;
    box-shadow: 0 1px 3px rgba(0,0,0,0.12), 0 1px 2px rgba(0,0,0,0.24);
    transform: scale(var(--scale));
    transition: 150ms transform;
    transform-origin: top center;
    z-index: 2;
  }

  &:hover::after {
    --scale: 1;
  }

  img {
    width: 60%;
  }

  ${props => props.disabled? "opacity: 0; pointer-events: none;" : "opacity: 1"};  
  ${props => props.opacity? "opacity: 0; pointer-events: none;" : ""};
`