import styled from 'styled-components'
import { Link } from 'react-router-dom'
import { Box, Container, createMuiTheme } from '@material-ui/core'
import background from '../../assets/images/capa/BG_Desktop.jpg'

const { breakpoints } = createMuiTheme()

export const StyledContainer = styled(Box)`
  max-width: 100vw;
  max-height: 100vh;
  display: flex;  
  flex-direction: column;
  overflow: hidden;


  @media(min-width: 900px) {
    background-size: 100% auto;
  }

  @keyframes slide {
    from {
      transform: translateX(-80px);
      opacity: 0;
    }

    to {
      transform: translateX(0);
      opacity: 1;
    }
  }
  h1{
    font-weight: bold;
    @media(max-width:900px){
      font-size: 4vh;
    }
  }
  h2{
    @media(max-width:900px){
      font-size: 3vh;
    }
  }

  #container{
    /* flex-grow: 1; */
    display: flex;
    padding-right: 0px;
    padding-left: 0px;
    background: url(${background}) no-repeat;
    background-size: cover;
  }

  #conteudo{
    height: 73vh;
    display: flex;
    width: 100%;
    flex-direction: column;
    justify-content: center;
    @media(max-width:900px){
      height: 80vh;
    }

  }

  #box-title{
    display: flex;
    flex-direction:column;
    justify-content: center;
    align-items: center;
  }
  #title{
    width: 55%;
    text-align: center;
    color: #fff;
    font-weight: bold;
    @media(max-width:900px){
      width: 90%;
    }
  }
  #subtitle{
    width: 65%;
    text-align: center;
    color: #fff;
    font-weight: bold;
    @media(max-width:900px){
      width: 90%;
    }
  }



  #button{
    display: flex;
    padding-top: 10px;
    align-items: center;
    justify-content: center;
  }

`

export const Iniciar = styled(Link)`
  background-color: ${props => props.theme.palette.button.iniciar};
  box-shadow: 0px 5px 5px 0px rgba(0,87,76,0.8);
  border-radius: 50px;
  width: 28vh;
  height: 7.43vh;
  margin: 20px 0;
  display: flex;
  align-items: center;
  justify-content: center;
  overflow: hidden;
  transition: all 0.3s cubic-bezier(.25,.8,.25,1);
  animation: slide both;
  animation-duration: 1s;
  animation-delay: 1s;

  @media(min-width: 900px){  
    width: 32vh;
    height: 8.5vh;
  }

  &:hover {
    background-color: ${props => props.theme.palette.button.dark};
    transition: all 0.3s cubic-bezier(.25,.8,.25,1);
    box-shadow: 0px 6px 7px 0px rgba(0,87,76,0.8);
    transform: scale(1.1);
  }

  img{
    width: 100%;
  }
`
